<?php
/**
 * ${Theme Name} back compat functionality
 *
 * Prevents ${Theme Name} from running on WordPress versions prior to ${minimum_wordpress_version},
 * since this theme is not meant to be backward compatible beyond that
 * and relies on many newer functions and markup changes introduced in ${minimum_wordpress_version}.
 *
 * @package ${Theme_Name}
 * @since ${child-theme-version-number:-0.1.0} ${Theme Name}
 */

add_action( 'after_switch_theme', 'theme_prefix_lowercase_underscore_no_spaces_switch_theme' );
/**
 * Prevent switching to ${Theme Name} on old versions of WordPress.
 *
 * Switches to the default theme.
 *
 * @since ${child-theme-version-number:-0.1.0} ${Theme Name}
 */
function theme_prefix_lowercase_underscore_no_spaces_switch_theme() {
	switch_theme( WP_DEFAULT_THEME, WP_DEFAULT_THEME );
	unset( $_GET['activated'] );
	add_action( 'admin_notices', 'theme_prefix_lowercase_underscore_no_spaces_upgrade_notice' );
}

/**
 * Add message for unsuccessful theme switch.
 *
 * Prints an update nag after an unsuccessful attempt to switch to
 * ${Theme Name} on WordPress versions prior to ${minimum_wordpress_version}.
 *
 * @since ${child-theme-version-number:-0.1.0} ${Theme Name}
 */
function theme_prefix_lowercase_underscore_no_spaces_upgrade_notice() {
	$message = sprintf( __( '${Theme Name} requires at least WordPress version %s.
	You are running version %s. Please upgrade and try again.',
			'${theme-name-lowercase-hyphen-no-spaces}' ),
			MINIMUM_WORDPRESS_VERSION, $GLOBALS['wp_version'] );
	printf( '<div class="error"><p>%s</p></div>', $message );
}

add_action( 'load-customize.php', 'theme_prefix_lowercase_underscore_no_spaces_customize' );
/**
 * Prevent the Theme Customizer from being loaded on WordPress versions prior to
 * ${minimum_wordpress_version}.
 *
 * @since ${child-theme-version-number:-0.1.0} ${Theme Name}
 */
function theme_prefix_lowercase_underscore_no_spaces_customize() {
	wp_die( sprintf( __( '${Theme Name} requires at least WordPress version %s. You
	are running version %s. Please upgrade and try again.',
			'${theme-name-lowercase-hyphen-no-spaces}' ),
			MINIMUM_WORDPRESS_VERSION, $GLOBALS['wp_version'] ),
			'',
			array(
					'back_link' => true,
			) );
}

add_action( 'template_redirect', 'theme_prefix_lowercase_underscore_no_spaces_preview' );
/**
 * Prevent the Theme Preview from being loaded on WordPress versions prior to
 * ${minimum_wordpress_version}.
 *
 * @since ${child-theme-version-number:-0.1.0} ${Theme Name}
 */
function theme_prefix_lowercase_underscore_no_spaces_preview() {
	if ( isset( $_GET['preview'] ) ) {
		wp_die( sprintf( __( '${Theme Name} requires at least WordPress version %s.
		You are running version %s. Please upgrade and try again.',
				'${theme-name-lowercase-hyphen-no-spaces}' ),
				MINIMUM_WORDPRESS_VERSION, $GLOBALS['wp_version'] ) );
	}
}
