<?php

/**
 * Customizer additions.
 *
 * For example: Accent color, Image upload and Color selection.
 *
 * @package ${Theme Name}
 * @author  BrewPixel
 * @link    http://brewpixel.com
 * @license GPL2-0+
 */

/**
 * Get default accent color for Customizer.
 *
 * Abstracted here since at least two functions use it.
 *
 * @since ${child-theme-version-number:-0.1.0} ${Theme Name}
 *
 * @return string Hex color code for accent color.
 */
function theme_prefix_lowercase_underscore_no_spaces_customizer_get_default_accent_color() {
	return '#ff4800';
}

/*
  Optional: We can add more default colours

/**
 * Get default header color for Customizer.
 *
 * Abstracted here since at least two functions use it.
 *
 * @since ${child-theme-version-number:-0.1.0} ${Theme Name}
 *
 * @return string Hex color code for header color.
 *
function author_customizer_get_default_header_color() {

    return '#7a8690';

}

/**
 * Get default light color for Customizer.
 *
 * Abstracted here since at least two functions use it.
 *
 * @since ${child-theme-version-number:-0.1.0} ${Theme Name}
 *
 * @return string Hex color code for light color.
 *
function author_customizer_get_default_light_color() {

    return '#e1e9ee';

}

/**
 * Get default dark color for Customizer.
 *
 * Abstracted here since at least two functions use it.
 *
 * @since ${child-theme-version-number:-0.1.0} ${Theme Name}
 *
 * @return string Hex color code for dark color.
 *
function author_customizer_get_default_dark_color() {

    return '#181c1e';

}
*/

add_action( 'customize_register', 'theme_prefix_lowercase_underscore_no_spaces_customizer_register' );
/**
 * Register settings and controls with the Customizer.
 *
 * @since ${child-theme-version-number:-0.1.0} ${Theme Name}
 *
 * @param WP_Customize_Manager $wp_customize Customizer object.
 */
function theme_prefix_lowercase_underscore_no_spaces_customizer_register() {

	/*
	Optional:
	/**
		 * Customize Background Image Control Class
		 *
		 * @package WordPress
		 * @subpackage Customize
		 * @since 3.4.0
		 *
		class Child_Altitude_Image_Control extends WP_Customize_Image_Control {

			/**
			 * Constructor.
			 *
			 * If $args['settings'] is not defined, use the $id as the setting ID.
			 *
			 * @since 3.4.0
			 * @uses WP_Customize_Upload_Control::__construct()
			 *
			 * @param WP_Customize_Manager $manager
			 * @param string $id
			 * @param array $args
			 *
			public function __construct( $manager, $id, $args ) {
				$this->statuses = array( '' => __( 'No Image', 'altitude' ) );

				parent::__construct( $manager, $id, $args );

				$this->add_tab( 'upload-new', __( 'Upload New', 'altitude' ), array( $this, 'tab_upload_new' ) );
				$this->add_tab( 'uploaded',   __( 'Uploaded', 'altitude' ),   array( $this, 'tab_uploaded' ) );

				if ( $this->setting->default )
					$this->add_tab( 'default',  __( 'Default', 'altitude' ),  array( $this, 'tab_default_background' ) );

				// Early priority to occur before $this->manager->prepare_controls();
				add_action( 'customize_controls_init', array( $this, 'prepare_control' ), 5 );
			}

			/**
			 * @since 3.4.0
			 * @uses WP_Customize_Image_Control::print_tab_image()
			 *
			public function tab_default_background() {
				$this->print_tab_image( $this->setting->default );
			}

		}
	*/
	global $wp_customize;

	$images = apply_filters( 'theme_prefix_lowercase_underscore_no_spaces_images', array( '1', '2' ) );

	$wp_customize->add_section( '${theme-name-lowercase-hyphen-no-spaces}-settings', array(
			'description' => __( 'Use the included default images or personalize your site by uploading your own images.<br /><br />The default images are <strong>1800 pixels wide and 500 pixels tall</strong>.', '${theme-name-lowercase-hyphen-no-spaces}' ),
			'title'    => __( 'Front Page Background Images', '${theme-name-lowercase-hyphen-no-spaces}' ),
			'priority' => 35,
	) );

	foreach ( $images as $image ) {

		$wp_customize->add_setting( $image . '-${theme-name-lowercase-hyphen-no-spaces}-image', array(
				'default'  => sprintf( '%s/images/bg-%s.jpg', get_stylesheet_directory_uri(), $image ),
				'type'     => 'option',
		) );

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, $image . '-${theme-name-lowercase-hyphen-no-spaces}-image', array(
				'label'    => sprintf( __( 'Featured Section %s Image:', '${theme-name-lowercase-hyphen-no-spaces}' ), $image ),
				'section'  => '${theme-name-lowercase-hyphen-no-spaces}-settings',
				'settings' => $image . '-${theme-name-lowercase-hyphen-no-spaces}-image',
				'priority' => $image + 1,
		) ) );

		/*
		Optional: If using child class above then also change this.
				$wp_customize->add_control( new Child_Altitude_Image_Control( $wp_customize, $image .'-altitude-image', array(
			'label'    => sprintf( __( 'Featured Section %s Image:', 'altitude' ), $image ),
			'section'  => 'altitude-settings',
			'settings' => $image .'-altitude-image',
			'priority' => $image+1,
		) ) );
		*/

	}

	$wp_customize->add_setting(
		'theme_prefix_lowercase_underscore_no_spaces_accent_color',
		array(
					'default' => theme_prefix_lowercase_underscore_no_spaces_customizer_get_default_accent_color(),
					'sanitize_callback' => 'sanitize_hex_color',
			)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'theme_prefix_lowercase_underscore_no_spaces_accent_color',
			array(
							'description' => __( 'Change the default accent color for links, buttons, and more.', '${theme-name-lowercase-hyphen-no-spaces}' ),
							'label'       => __( 'Accent Color', '${theme-name-lowercase-hyphen-no-spaces}' ),
							'section'     => 'colors',
							'settings'    => 'theme_prefix_lowercase_underscore_no_spaces_accent_color',
					)
		)
	);

	// @codingStandardsIgnoreStart
	/*
	Optional if adding other customizer colours
		$wp_customize->add_setting(
		'author_header_color',
		array(
			'default' => author_customizer_get_default_header_color(),
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'author_header_color',
			array(
				'label'    => __( 'Header Background Color', 'author' ),
				'description' => __( 'Change the header background color. You can use the same color as the background color, if desired.', 'author' ),
				'section'  => 'colors',
				'settings' => 'author_header_color',
			)
		)
	);

	$wp_customize->add_setting(
		'author_light_color',
		array(
			'default' => author_customizer_get_default_light_color(),
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'author_light_color',
			array(
				'label'    => __( 'Light Color', 'author' ),
				'description' => __( 'Change the light background color for areas such as the secondary navigation and sidebar.', 'author' ),
				'section'  => 'colors',
				'settings' => 'author_light_color',
			)
		)
	);

	$wp_customize->add_setting(
		'author_dark_color',
		array(
			'default' => author_customizer_get_default_dark_color(),
			'sanitize_callback' => 'sanitize_hex_color',
		)
	);

	$wp_customize->add_control(
		new WP_Customize_Color_Control(
			$wp_customize,
			'author_dark_color',
			array(
				'label'    => __( 'Dark Color', 'author' ),
				'description' => __( 'Change the dark background color for areas such as submenus and footer widgets.', 'author' ),
				'section'  => 'colors',
				'settings' => 'author_dark_color',
			)
		)
	);
	*/
	// @codingStandardsIgnoreEnd

}

// @codingStandardsIgnoreStart
// add_action( 'customize_register', 'themeprefix_customizer_featured_image' );
/*
function themeprefix_customizer_featured_image() {
	global $wp_customize;

	// Add featured image section to the Customizer
	$wp_customize->add_section(
		'themeprefix_single_image_section',
		array(
			'title'       => __( 'Post and Page Images', 'themeprefix' ),
			'description' => __( 'Choose if you would like to display the featured image above the content on single posts and pages.', 'themeprefix' ),
			'priority' => 200, // puts the customizer section lower down
		)
	);
	// Add featured image setting to the Customizer
	$wp_customize->add_setting(
		'themeprefix_single_image_setting',
		array(
			'default'           => true, // set the option as enabled by default
			'capability'        => 'edit_theme_options',
		)
	);
	$wp_customize->add_control(
		'themeprefix_single_image_setting',
		array(
			'section'   => 'themeprefix_single_image_section',
			'settings'  => 'themeprefix_single_image_setting',
			'label'     => __( 'Show featured image on posts and pages?', 'themeprefix' ),
			'type'      => 'checkbox'
		)
	);
}
*/
// @codingStandardsIgnoreEnd
