<?php
/*
 * Adds the required CSS to the front end.
 */

add_action( 'wp_enqueue_scripts', 'theme_prefix_lowercase_underscore_no_spacescss' );
/**
 * Checks the settings for the images and background colors for each image
 * If any of these value are set the appropriate CSS is output
 *
 * @since ${child-theme-version-number:-0.1.0} ${Theme Name}
 */
function theme_prefix_lowercase_underscore_no_spacescss() {

	$handle  = defined( 'CHILD_THEME_NAME' ) && CHILD_THEME_NAME ? sanitize_title_with_dashes( CHILD_THEME_NAME ) : 'child-theme';

	// $header_color = get_theme_mod( 'author_header_color', author_customizer_get_default_header_color() );
	// $light_color = get_theme_mod( 'author_light_color', author_customizer_get_default_light_color() );
	// $dark_color = get_theme_mod( 'author_dark_color', author_customizer_get_default_dark_color() );
	// $accent_color = get_theme_mod( 'author_accent_color', author_customizer_get_default_accent_color() );
	$color = get_theme_mod( 'theme_prefix_lowercase_underscore_no_spacesaccent_color', theme_prefix_lowercase_underscore_no_spacescustomizer_get_default_accent_color() );

	$opts = apply_filters( 'theme_prefix_lowercase_underscore_no_spacesimages', array( '1', '2' ) );

	$settings = array();

	foreach ( $opts as $opt ) {
		$settings[ $opt ]['image'] = preg_replace( '/^https?:/', '', get_option( $opt . '-brewpixel-image', sprintf( '%s/images/bg-%s.jpg', get_stylesheet_directory_uri(), $opt ) ) );
	}

	$css = '';

	foreach ( $settings as $section => $value ) {

		$background = $value['image'] ? sprintf( 'background-image: url(%s);', $value['image'] ) : '';

		if ( is_front_page() ) {
			$css .= ( ! empty( $section ) && ! empty( $background ) ) ? sprintf( '.image-section-%s { %s }', $section, $background ) : '';
		}
	}

	/*
	Optional if using other customizer colours:
	$css .= ( author_customizer_get_default_header_color() !== $header_color ) ? sprintf( '
			.site-header {
				background-color: %1$s;
			}
			', $header_color ) : '';

		$css .= ( author_customizer_get_default_light_color() !== $light_color ) ? sprintf( '
			blockquote::before,
			.nav-primary:hover .genesis-nav-menu a,
			.nav-secondary .genesis-nav-menu .sub-menu a {
				color: %1$s;
			}

			.content .widget-full .featuredpost,
			.nav-secondary,
			.sidebar .widget {
				background-color: %1$s;
			}
			', $light_color ) : '';

		$css .= ( author_customizer_get_default_dark_color() !== $dark_color ) ? sprintf( '
			.content .widget-full .featuredpage,
			.genesis-nav-menu .sub-menu,
			.genesis-nav-menu .sub-menu li a,
			.footer-widgets .wrap,
			.nav-secondary .genesis-nav-menu a:hover,
			.nav-secondary .genesis-nav-menu .current-menu-item > a,
			.nav-secondary .genesis-nav-menu .sub-menu .current-menu-item > a:hover,
			.site-footer .wrap,
			.widget-full .featured-content .widget-title {
				background-color: %1$s;
			}
			', $dark_color ) : '';

		$css .= ( author_customizer_get_default_accent_color() !== $accent_color ) ? sprintf( '
			a,
			.archive-pagination li a:hover,
			.archive-pagination .active a,
			.entry-title a:hover,
			.footer-widgets a:hover,
			.site-footer a:hover {
				color: %1$s;
			}

			.nav-secondary .genesis-nav-menu .highlight > a {
				background-color: %1$s;
			}
			', $accent_color ) : '';
	 */
	$css .= ( theme_prefix_lowercase_underscore_no_spacescustomizer_get_default_accent_color() !== $color ) ? sprintf( '
		a,
		.add-black .after-header a:focus,
		.add-black .after-header a:hover,
		.author-box-title,
		.archive-pagination li a:focus,
		.archive-pagination li a:hover,
		.archive-pagination .active a,
		.archive-title,
		.entry-header .entry-meta,
		.entry-title a:focus,
		.entry-title a:hover,
		.featured-content .entry-meta,
		.flexible-widgets .featured-content .has-post-thumbnail .alignnone + .entry-header .entry-title a:focus,
		.flexible-widgets .featured-content .has-post-thumbnail .alignnone + .entry-header .entry-title a:hover,
		.footer-widgets a:focus,
		.footer-widgets a:hover,
		.front-page-3 a:focus,
		.front-page-3 a:hover,
		.genesis-nav-menu .sub-menu a:focus,
		.genesis-nav-menu .sub-menu a:hover,
		.nav-secondary .genesis-nav-menu .sub-menu a:focus,
		.nav-secondary .genesis-nav-menu .sub-menu a:hover,
		.nav-secondary .genesis-nav-menu .sub-menu .current-menu-item > a,
		.page-title,
		.site-footer a:focus,
		.site-footer a:hover,
		.widget li a:focus,
		.widget li a:hover,
		.widget-title {
			color: %1$s;
		}

		button,
		input[type="button"],
		input[type="reset"],
		input[type="submit"],
		.add-color .after-header,
		.add-color .site-header,
		.button,
		.widget .button {
			background-color: %1$s;
		}

		.after-header,
		.front-page-1,
		.genesis-nav-menu .sub-menu,
		.genesis-nav-menu > .current-menu-item > a,
		.genesis-nav-menu > li > a:focus,
		.genesis-nav-menu > li > a:hover {
			border-color: %1$s;
		}

		@media only screen and (max-width: 880px) {
			.js nav .genesis-nav-menu .menu-item .sub-menu li a:focus,
			.js nav .genesis-nav-menu .menu-item a:focus,
			.js nav button:focus,
			.js .menu-toggle:focus {
				color: %1$s;
			}
		}
		', $color ) : '';

	if ( $css ) {
		wp_add_inline_style( $handle, $css );
	}

}
