<?php
/*
 * ---------------------------------------------------------------------------*\
 *  #TEMPLATE TAGS
 * ---------------------------------------------------------------------------
 */

/**
 * Open post title.
 */
function theme_prefix_lowercase_underscore_no_spaces_open_post_title() {
	echo '';
}

/**
 * Close post title.
 */
function theme_prefix_lowercase_underscore_no_spaces_close_post_title() {
	echo '';
}

/**
 * Open div.
 */
function theme_prefix_lowercase_underscore_no_spaces_open_div_generic() {
	echo '<div>';
}

/**
 * Close div.
 */
function theme_prefix_lowercase_underscore_no_spaces_close_div_generic() {
	echo '</div>';
}

/**
 * Show page editor content from page.
 *
 * @param string $page_slug The page slug of the page.
 * @param string $imagesize Image size.
 * @param null   $imageclass Image class.
 *
 * @return string|void
 */
function theme_prefix_lowercase_underscore_no_spaces_show_page_content( $page_slug, $imagesize = 'medium', $imageclass = null ) {
	global $post;
	if ( isset( $page_slug ) ) {
		$page = get_posts( array(
			'name'      => $page_slug,
			'post_type' => 'page',
		) );

		if ( $page ) {
			$content = $page[0]->post_content;
			$content = apply_filters( 'the_content', $content );
			$content = get_the_post_thumbnail( $page[0]->ID, $imagesize, array( 'class' => $imageclass ) ) . $content;

			return '<div class="intro-content">' . $content . '</div>';
		}
	} else {
		return;
	}
}

/**
 * Add page description.
 */
function theme_prefix_lowercase_underscore_no_spaces_add_page_description() {

	echo '<div class="page-description">';
	echo '<h1 itemprop="headline" class="page-title">' . get_the_title() . '</h1>';
	echo '<p>' . get_the_excerpt() . '</p></div>'; // WPCS: XSS OK.

}

/**
 * Add post info to pages.
 */
function theme_prefix_lowercase_underscore_no_spaces_add_post_info_pages() {
	if ( is_page() ) {
		$post_info = '[post_date] ' . __( 'by', 'genesis' ) . ' [post_author_posts_link] [post_comments] [post_edit]';
		printf( '<p class=”entry-meta”>%s</p>', do_shortcode( $post_info ) );
	}
}

/**
 * Add post info to pages.
 */
function theme_prefix_lowercase_underscore_no_spaces_add_custom_post_info() {
	?>
	<div class="post-info">
		<span class="date published time">
			<time class="entry-date" itemprop="startDate"
			      datetime="<?php echo get_the_date( 'c' ); ?>"
			      pubdate>
				<?php echo get_the_date(); ?>
			</time>
		</span> By
		<span class="author vcard">
			<a class="fn n"
			   href="<?php echo get_the_author_meta( 'url' ); ?>"
			   title="View <?php echo get_the_author(); ?>'s Profile"
			   rel="author me"><?php the_author_meta( 'display_name' ); ?></a>
		</span>
		<span class="post-comments">&middot; <a
				href="<?php the_permalink() ?>#comments">
				<?php comments_number( 'Leave a Comment', '1 Comment', '% Comments' ); ?>
			</a>
		</span>
		<?php // if the post has been modified, display the modified date
		$published         = get_the_date( 'F j, Y' );
		$modified          = the_modified_date( 'F j, Y', '', '', false );
		$published_compare = get_the_date( 'Y-m-d' );
		$modified_compare  = the_modified_date( 'Y-m-d', '', '', false );
		echo '<span class="published">' . $published . ')</span>';
		if ( $published_compare < $modified_compare ) {
			echo ' <span class="updated"><em>&middot; (Updated: ' . $modified . ')</em></span>';
		} ?>
	</div>
	<?php
}

/**
 * Get a person's name and the company or organisation they are with.
 *
 * If we know the person's name and their company/organisation then retrieve
 * that otherwise retrieve just the person's name or just the
 * company/organisation name.
 *
 * @return string
 */
function theme_prefix_lowercase_underscore_no_spaces_get_company_person_names() {
	$company          = get_post_meta( get_the_ID(), 'info_organisation', true );
	$personnfirstname = get_post_meta( get_the_ID(), 'info_first_name(s)', true );
	$personnlastname  = get_post_meta( get_the_ID(), 'info_last_name', true );
	$personname       = $personnfirstname ? $personnfirstname . ' ' . $personnlastname : '';

	if ( $company && $personname ) {
		$name = $personname . ' &ndash; <span class="testimonial__company">' . $company . '</span>';
	} elseif ( $company ) {
		$name = '<span class="testimonial__company">' . $company . '</span>';
	} elseif ( $personname ) {
		$name = $personname;
	} else {
		$name = '';
	}

	return $name;
}

/**
 * Show testimonial(s).
 *
 * @param int $number_of_testimonials
 * @param string $before
 * @param string $after
 * @param int|false $id
 * @param string $imagesize
 */
function theme_prefix_lowercase_underscore_no_spaces_do_testimonial( $number_of_testimonials = 1, $before = '', $after = '', $id = 0, $imagesize = null ) {
	$id          = 0 === $id ? get_the_ID() : $id;
	$testimonial = get_transient( 'testimonial-' . $id );

	if ( false === $testimonial || $testimonial->posts_per_page !== $number_of_testimonials ) {
		// It wasn't there, so regenerate the data and save the transient.
		$args = array(
			'post_type'      => 'brew_testimonial',
			'posts_per_page' => $number_of_testimonials,
			'meta_key'       => 'info_show_as_a_feature_testimonial',
			'meta_query'     => array(
				array(
					'key'     => 'info_show_as_a_feature_testimonial',
					'value'   => 'Show as a feature testimonial',
					'compare' => '=',
				),
			),
			'orderby'        => 'rand',
		);

		$testimonial = new WP_Query( $args );

		set_transient( 'testimonial-' . $id, $testimonial, 1 * MINUTE_IN_SECONDS );
	}

	if ( $testimonial->have_posts() ) :
		while ( $testimonial->have_posts() ) :
			$testimonial->the_post();
			$testimonial_quote = wpautop( get_post_meta( get_the_ID(), 'testimonial_or_review_pull_quote', true ) );
			$date              = get_post_meta( get_the_ID(), 'info_date', true );
			echo $before;
			echo '
			<div class="c-testimonial">
				<div class="c-testimonial__row">
					<div class="c-testimonial__row__item">' . theme_prefix_lowercase_underscore_no_spaces_get_feature_image( array(
						'format' => 'html',
						'post'   => $id,
						'size'   => $imagesize,
					)
				) . '
					</div>
					<div class="c-testimonial__row__item">
						<div class="c-testimonial__meta">
							<span>' . theme_prefix_lowercase_underscore_no_spaces_get_company_person_names() . '</span>
						</div>
					</div>
					<span class="screen-reader-text">' . $date . '</span>
				</div>
				<!-- With autop -->
				' . $testimonial_quote . '
			</div>';
			echo $after;
		endwhile; // End of the loop.
		?>

		<?php
		wp_reset_postdata();
	endif;


}

/**
 * Return the feature image if there is one in the format requested.
 * Use a fallback image from the entry content if there is one.
 * Use a fallback image from the theme's images directory if there is no
 * featured image set and none within the content to use.
 *
 * When a theme adds 'post-thumbnail' support, a special 'post-thumbnail'
 * image size is registered, which differs from the 'thumbnail' image size
 * managed via the Settings > Media screen.
 *
 * When using the_post_thumbnail() or related functions, the 'post-thumbnail'
 * image size is used by default, though a different size can be specified
 * instead as needed.
 *
 * Requirements:
 *
 * // post thumbnail support for the
 * // Register a custom image size for hero images on single Posts
 * add_image_size( 'post-image', 1600, 400, true );
 *
 * // Set circumstances to use function or not. For example if we are not on a
 * single Post, abort.
 * if ( !is_singular( 'post' ) ) {
 *  return;
 * }
 *
 * @TODO: Break this function down into smaller ones and allow this function to be higher level.
 * @TODO: Add itemprop="image", class="entry-image" or itemprop="image" as default.
 * @TODO: Test all arguments will accept what they say they will and produce appropriate results. For example the size parameter with an array of values.
 * @TODO: If $image returns as false then use a fallback.
 * @TODO: Do we want to replicate the genesis_get_image function if it does
 * not exist or did this function pre-date the WordPress function get_the_post_thumbnail() and so we should use that instead?
 * @TODO: Make sure responsive images are output.
 *
 * If using Genesis:
 * Applies `genesis_get_image_default_args`, `genesis_pre_get_image` and `genesis_get_image` filters.
 *
 * Supported $args keys are:
 *
 *    - post: integer|WP_Post $post Optional. Post ID or WP_Post object.  Default is global `$post`.
 *    - format: string $args['format'] Optional. Format to output.
 *        - 'html' for img element,
 *        - 'url' for image url,
 *        - 'src' source relative to root. Example: If your image were in “http://example.com/wp-content/uploads/2011/05/img.jpg” then it would return "wp-content/uploads/2011/05/img.jpg"
 *        - 'background' for background image html.
 *      Default is 'html'.
 *    - size: string|array|void $size Optional. Image size to use. Accepts any valid image size, or an array of width and height values in pixels (in that order). While `$size` will accept an array, it is better to register a size with add_image_size() so that a cropped version is generated. It's much more
 * efficient than having to find the closest-sized image and then having the
 * browser scale down the image. Default 'post-thumbnail'.
 *    - num: integer $num The attached image to return. 0 is the default and will return the first attached image if no featured image is set. Using a value of 1 or greater will return the 2nd or greater attached image, but will override the featured image.
 *    - attr: string|array $attr Optional. Query string or array of attributes.
 * Default array( 'alt' => get_the_title(), 'class' => 'post-image entry-image', 'itemprop' => 'image' ).
 *    - fallback: string|integer $fallback 'first-attached' or post_id of image
 *    - context: Default ''
 *    - remove_genesis_image_alignment: boolean $remove_genesis_image_alignment Default: false
 *
 * @since ${child-theme-version-number:-0.1.0} ${Theme Name}
 *
 * @param array|string $args Optional. Image query arguments. Default is empty array.
 *
 * @return string|bool Return the post thumbnail image or the attachment URL or the relative source or HTML for a background image or `false`.
 */
function theme_prefix_lowercase_underscore_no_spaces_get_feature_image( array $args = array() ) {
	$image    = '';
	$defaults = array(
		'post'                           => null,
		'format'                         => 'html',
		'size'                           => 'post-thumbnail',
		'num'                            => 0,
		'attr'                           => array(
			'alt'      => get_the_title(),
			'class'    => 'post-image entry-image',
			'itemprop' => 'image'
		),
		'fallback'                       => 'first-attached',
		'context'                        => '',
		'echo'                           => false,
		'remove_genesis_image_alignment' => false,
	);

	$args = wp_parse_args( $args, $defaults );
	$post = get_post( $args['post'] );
	if ( ! $post ) {
		return false;
	}
	$size = $args['size'] ?: 'post-thumbnail';
	$size = apply_filters( 'post_thumbnail_size', $size );

	if ( 'url' === $args['format'] ) {
		$image = get_the_post_thumbnail_url( $post, $size );
	} elseif ( 'html' === $args['format'] ) {
		if ( function_exists( 'genesis_get_image' ) ) {
			// get the URL of featured image or the HTML for it or source
			$image = genesis_get_image( array(
					'post_id'  => $post->ID,
					'format'   => 'html',
					// url or html or source relative to root
					'size'     => $size,
					'num'      => $args['num'],
					'attr'     => $args['attr'],
					// set a default WP image class
					'fallback' => $args['fallback'],
					'context'  => $args['context'],
				)
			);
		} elseif ( has_post_thumbnail( $post ) ) {
			$image = get_the_post_thumbnail( $post, $size, $args['attr'] );
		} else {
			$imageurl = get_stylesheet_directory_uri() . '/images/default-feature-image.jpg';
			// get the alt text of featured image
			$thumb_id = get_post_thumbnail_id( $post );
			$alt      = get_post_meta( $thumb_id, '_wp_attachment_image_alt', true );

			// if no alt text is present for featured image, set it to Post title
			if ( '' === $alt ) {
				$alt = the_title_attribute( 'echo=0' );
			}

			// display the featured image
			$image = sprintf( '<img src="%s" alt="%s" />', esc_url( $imageurl ), $alt );
		}

		// $image = get_avatar( 'defaultavatar@thefinalstep.co.uk', 45 );
	} elseif ( 'src' === $args['format'] ) {
		if ( function_exists( 'genesis_get_image' ) ) {
			// get the URL of featured image or the HTML for it or source
			$image = genesis_get_image( array(
					'post_id'  => $post->ID,
					'format'   => 'src',
					// url or html or source relative to root
					'size'     => $size,
					'num'      => $args['num'],
					'attr'     => $args['attr'],
					// set a default WP image class
					'fallback' => $args['fallback'],
					'context'  => $args['context'],
				)
			);
		}
	} elseif ( 'background' === $args['format'] ) {
		$imageurl    = get_the_post_thumbnail_url( $post, $size );
		$overlaytext = genesis_do_post_title();
		$image       = sprintf( "<div class='post-hero' style='background-image: url( %s )'><div class='wrap'>%s</div></div>", esc_url( $imageurl ), $overlaytext );
	}

	if ( $args['echo'] ) {
		theme_prefix_lowercase_underscore_no_spaces_do_feature_image( $image );
	} else {
		if ( $image ) {
			return $image;
		}

		return false;
	}

	// $image = get_avatar( 'defaultavatar@thefinalstep.co.uk', 45 );
	// get the alt text of featured image
	$thumb_id = get_post_thumbnail_id( get_the_ID() );
	$alt      = get_post_meta( $thumb_id, '_wp_attachment_image_alt', true );

	// if no alt text is present for featured image, set it to Post title
	if ( '' === $alt ) {
		$alt = the_title_attribute( 'echo=0' );
	}

	// display the featured image
	// printf( '<div class="single-post-image"><img src="%s" alt="%s" /></div>', esc_url( $image ), $alt );
}

function theme_prefix_lowercase_underscore_no_spaces_do_feature_image( $image ) {
	if ( ! empty( $image ) ) {
		if ( function_exists( 'genesis_markup' ) ) {
			genesis_markup( array(
				'open'    => '<a %s>',
				'close'   => '</a>',
				'content' => wp_make_content_images_responsive( $image ),
				'context' => 'entry-image-link',
			) );
		}
	}
}

// @TODO Improve this to use the correct image size argument.
function brewpixel_do_page_image() {
	$img = genesis_get_image( array(
		'format'  => 'html',
		'size'    => genesis_get_option( 'image_size' ),
		'context' => 'page',
		'attr'    => array(
			'alt' => get_the_title(),
			'class' => 'post-image entry-image',
			'itemprop' => 'image',
		),
	) );

	if ( ! empty( $img ) ) {

		genesis_markup( array(
			'html5'   => '<a %s>',
			'xhtml'   => '<a href="' . get_permalink() . '" class="entry-image-link" aria-hidden="true">',
			'context' => 'entry-image-link',
		) );

		echo wp_kses_post( $img . '</a>' );

	}
}

// @TODO: Are we showing a header CTA widget area?
/**
 * Get the sidebar widgets for the Header CTA area.
 *
 * @return string|bool
 */
/*
function theme_prefix_lowercase_underscore_no_spaces_show_header_cta() {
	if ( is_active_sidebar( 'theme_prefix_lowercase_underscore_no_spaces_header_cta' ) ) {
		return dynamic_sidebar( 'theme_prefix_lowercase_underscore_no_spaces_header_cta' );
	}
	return false;
}
*/

// @TODO: Do we need to get the parent taxonomies terms?
/**
 * Get parent taxonomies terms.
 *
 * @param string $taxonomy_slug The slug for the taxonomy.
 *
 * @return string
 */
/*
function theme_prefix_lowercase_underscore_no_spaces_custom_parent_taxonomies_terms( $taxonomy_slug ) {
	global $post;

	$out = array();

	// Get the terms related to post.
	$terms = get_the_terms( $post->ID, $taxonomy_slug );

	if ( ! empty( $terms ) && false !== $terms && ! is_wp_error( $terms ) ) {
		$out[] = '';
		foreach ( (array) $terms as $term ) {
			if ( 0 === $term->parent ) {
				$out[] = $term->name;
			}
		}
	}

	return implode( '', $out );
}
*/

// @TODO: Do we need to display the taxonomies for the terms?
/**
 * Get taxonomies terms links.
 *
 * @param string      $taxonomy_slug The slug for the taxonomy.
 * @param string|null $taxonomy_display_name The display name you want to show in the HTML.
 *
 * @return string
 */
/*
function theme_prefix_lowercase_underscore_no_spaces_custom_taxonomies_terms_links( $taxonomy_slug, $taxonomy_display_name = null ) {
	global $post;

	$out = array();

	// Get the terms related to post.
	$terms = get_the_terms( $post->ID, $taxonomy_slug );

	if ( ! empty( $terms ) && false !== $terms && ! is_wp_error( $terms ) ) {
		$out[] = ( $taxonomy_display_name ? '<h2>' . ucwords( $taxonomy_slug ) . '</h2>\n<ul>' : '<ul>' );
		foreach ( (array) $terms as $term ) {
			$out[] =
				'  <li><a href="'
				. get_term_link( $term->slug, $taxonomy_slug ) . '">'
				. $term->name
				. "</a></li>\n";
		}
		$out[] = "</ul>\n";
	}

	return implode( '', $out );
}
*/

// @TODO: Do we need to alter the query for a taxonomy?
//add_action( 'pre_get_posts', 'theme_prefix_lowercase_underscore_no_spaces_custom_sector_taxonomy_archive_display' );
/**
 * Set the query for taxonomy archives.
 *
 * @param WP_Query $query The query object.
 */
/*
function theme_prefix_lowercase_underscore_no_spaces_custom_sector_taxonomy_archive_display( $query ) {
	if ( $query->is_main_query() && is_tax( 'sector' ) ) {
		$query->set( 'posts_per_page', '300' );
		$query->set( 'orderby', 'title' );
		$query->set( 'order', 'ASC' );
	}
}
*/

// @TODO: Do we need to alter the query for a taxonomy?
//add_action( 'pre_get_posts', 'theme_prefix_lowercase_underscore_no_spaces_custom_location_taxonomy_archive_display' );
/**
 * Set the query for taxonomy archives.
 *
 * @param WP_Query $query The query object.
 */
/*
function theme_prefix_lowercase_underscore_no_spaces_custom_location_taxonomy_archive_display( $query ) {
	if ( $query->is_main_query() && is_tax( 'location' ) ) {
		$query->set( 'posts_per_page', '10' );
		$query->set( 'orderby', 'menu_order' );
		$query->set( 'order', 'ASC' );
	}
}
*/

// @TODO: Do we need to allow more CSS style content in the post content?
//add_filter( 'safe_style_css', 'theme_prefix_lowercase_underscore_no_spaces_add_allowed_attributes_safe_css_style_kses_post' );
/**
 * Allow style attribute to be used in post content.
 */
/*
function theme_prefix_lowercase_underscore_no_spaces_add_allowed_attributes_safe_css_style_kses_post() {
	$styles[] = 'top';
	$styles[] = 'left';
	$styles[] = 'bottom';
	$styles[] = 'right';

	return $styles;
}
*/

/*
  Commenting out the content width code until we can determine if we want to
use it. See:
    http://codex.wordpress.org/Content_Width
    http://wycks.wordpress.com/2013/02/14/why-the-content_width-wordpress-global-kinda-sucks/
    https://core.trac.wordpress.org/ticket/21256
* Adjust content_width value for image attachment template.
*
* @since ${child-theme-version-number:-0.1.0} ${Theme Name}
function theme_prefix_lowercase_underscore_no_spaces_content_width() {
    if ( is_attachment() && wp_attachment_is_image() ) {
        $GLOBALS['content_width'] = 810;
    }
}
add_action( 'template_redirect', 'theme_prefix_lowercase_underscore_no_spaces_content_width' );

 * Set up the content width value based on the theme's design.
 *
 * @see theme_prefix_lowercase_underscore_no_spaces_content_width()
 *
 * @since ${child-theme-version-number:-0.1.0} ${Theme Name}
if ( ! isset( $content_width ) ) {
    $content_width = 474;
}
*/

// Uncomment if you need to add to the POST CLASSES and alter logic and class names as required.
/**
 * Extend the default WordPress post classes.
 *
 * Adds a post class to denote:.
 * Non-password protected page with a post thumbnail.
 *
 * @since ${child-theme-version-number:-0.1.0} ${Theme Name}
 *
 * @param array $classes A list of existing post class values.
 *
 * @return array The filtered post class list.
 *
 * function theme_prefix_lowercase_underscore_no_spaces_post_classes( $classes ) {
 * if ( ! post_password_required() && ! is_attachment() && has_post_thumbnail
 * () ) {
 * $classes[] = 'has-post-thumbnail';
 * }
 *
 * return $classes;
 * }
 * add_filter( 'post_class', 'theme_prefix_lowercase_underscore_no_spaces_post_classes' );
 */

/* GROUP Pagination */

/**
 * Function that Rounds To The Nearest Value.
 * Needed for the pagenavi() function.
 *
 * @param int $num Number.
 * @param int $to_nearest Rounding to nearest.
 *
 * @return float
 */
function theme_prefix_lowercase_underscore_no_spaces_round_num( $num, $to_nearest ) {
	// Round fractions down (http://php.net/manual/en/function.floor.php).
	return floor( $num / $to_nearest ) * $to_nearest;
}

// @TODO: Do we need to do this?
// add_filter( 'dynamic_sidebar_before', 'theme_prefix_lowercase_underscore_no_spaces_open_wrap_primary_sidebar', 10, 1 );
/**
 * Open div at start of primary sidebar.
 *
 * @param string $index The name/id of sidebar.
 */
/*
function theme_prefix_lowercase_underscore_no_spaces_open_wrap_primary_sidebar( $index ) {
	if ( 'sidebar' === $index ) {
		echo '<div class="l-grid-flex l-grid-flex--start l-grid-flex--gutters-m l-grid-flex--mq-580-up l-grid-flex--cols-2-mq-580-up l-grid-flex--cols-3-mq-930-up l-grid-flex--cols-4-mq-1570-up">';
	}
}
*/

// add_filter( 'dynamic_sidebar_after', 'theme_prefix_lowercase_underscore_no_spaces_close_wrap_primary_sidebar', 10, 1 );
/**
 * Open div at start of primary sidebar.
 *
 * @param string $index The name/id of sidebar.
 */
/*
function theme_prefix_lowercase_underscore_no_spaces_close_wrap_primary_sidebar( $index ) {
	if ( 'sidebar' === $index ) {
		echo '</div>';
	}
}
*/
